@@ -113,7 +113,7 @@ int main (int argc, char *argv[])
 	for (i=1; i<argc; i++){
 		const char *arg = argv[i];
 		const char *opt = argv[i+1];
-		if (strcmp(arg,"--ip")==0){
+		if (strcmp(arg,"--ip")==0 && opt != NULL){
 			unsigned long addr,mask;
 			if (nbaddrs == 16){
 				fprintf (stderr,"Too many IP numbers, max 16, ignored\n");
@@ -161,7 +161,7 @@ int main (int argc, char *argv[])
 				addrs[nbaddrs++] = addr;
 			}
 			i++;
-		}else if (strcmp(arg,"--bcast")==0){
+		}else if (strcmp(arg,"--bcast")==0 && opt != NULL){
 			unsigned long tmp;
 			if (ifconfig_getaddr(opt,tmp,tmp,bcast)==-1){
 				struct hostent *h = gethostbyname (opt);
