@@ -45,5 +45,8 @@ else
 	fi
 	cp -a $USR_LIB_VSERVER/vreboot $VROOT/sbin/.
 	ln -sf vreboot $VROOT/sbin/vhalt
+	if [ -x /etc/vservers/install-post.sh ]; then
+		/etc/vservers/install-post.sh $VROOT
+	fi
 fi
 
