@@ -189,31 +189,16 @@ int vbuild_file_copy(
 */
 void vutil_loadallpkg (string &refserver, list<PACKAGE> &packages)
 {
-	string cmd = "/usr/sbin/chroot " + refserver + " /bin/rpm -qa"
-		+ " --queryformat \"%{name}=%{version}-%{release}\\n\"";
-	// cout << "command " << cmd << endl;
-	#if 0
-		cmd = "| " + cmd;
-		ipfstream oo (cmd.c_str());
-		copy (istream_iterator<string>(oo),istream_iterator<string>()
-			,inserter(packages,packages.begin()));
-		int status;
-		wait (&status);
-	#else
-		FILE *fin = popen (cmd.c_str(),"r");
-		if (fin == NULL){
-			fprintf (stderr,"Can't execute %s (%s)\n",cmd.c_str()
-				,strerror(errno));
-		}else{
-			char line[1000];
-			while (fgets(line,sizeof(line)-1,fin)!=NULL){
-				int last = strlen(line)-1;
-				if (last >= 0 && line[last] == '\n') line[last] = '\0';
-				packages.push_back (PACKAGE(line));
-			}
-			pclose (fin);
+	FILE *fin = vutil_execdistcmd (K_PKGVERSION,refserver,NULL);
+	if (fin != NULL){
+		char line[1000];
+		while (fgets(line,sizeof(line)-1,fin)!=NULL){
+			int last = strlen(line)-1;
+			if (last >= 0 && line[last] == '\n') line[last] = '\0';
+			packages.push_back (PACKAGE(line));
 		}
-	#endif
+		pclose (fin);
+	}
 }
 
 int vutil_lstat (string path, struct stat &st)
@@ -227,3 +212,35 @@ int vutil_lstat (string path, struct stat &st)
 	return ret;
 }
 
+const char K_PKGVERSION[]="pkgversion";
+const char K_DUMPFILES[]="dumpfiles";
+const char K_UNIFILES[]="unifiles";
+
+FILE *vutil_execdistcmd (const char *key, const string &vserver, const char *args)
+{
+	string cmd = "/usr/lib/vserver/distrib-info ";
+	cmd += vserver;
+	cmd += " ";
+	cmd += key;
+	if (args != NULL){
+		cmd += " ";
+		cmd += args;
+	}
+	FILE *ret = popen (cmd.c_str(),"r");
+	if (ret == NULL){
+		fprintf (stderr,"Can't execute command %s\n",cmd.c_str());
+	}else{
+		#if 0
+		char buf[1000];
+		while (fgets(buf,sizeof(buf)-1,fin)!=NULL){
+			int last = strlen(buf)-1;
+			if (last >= 0) buf[last] = '\0';
+			ret = buf;
+			break;
+		}
+		pclose (fin);
+		#endif
+	}
+	return ret;
+}
+
